# Laboratory

Management of a group of people and their publications is made with the {class}`~gismap.lab.labmap.LabMap` abstract class.

## LabMaps

```{eval-rst}
.. automodule:: gismap.lab.labmap
    :members:
```

## EgoMaps

```{eval-rst}
.. automodule:: gismap.lab.egomap
    :members:
```

## Utilities

### Lab author

```{eval-rst}
.. automodule:: gismap.lab.lab_author
    :members:
```

### Expansion

```{eval-rst}
.. automodule:: gismap.lab.expansion
    :members:
```

### Filters

```{eval-rst}
.. automodule:: gismap.lab.filters
    :members:
```
